@@ -15,7 +15,7 @@
 import datetime
 import os
 
-from django.core.exceptions import ValidationError  # noqa
+from django.core.exceptions import ValidationError
 import django.template
 from django.template import defaultfilters
 
@@ -23,7 +23,7 @@ from horizon import forms
 from horizon.test import helpers as test
 from horizon.utils import filters
 # we have to import the filter in order to register it
-from horizon.utils.filters import parse_isotime  # noqa
+from horizon.utils.filters import parse_isotime  # noqa: F401
 from horizon.utils import functions
 from horizon.utils import memoized
 from horizon.utils import secret_key
@@ -194,6 +194,30 @@ class ValidatorsTests(test.TestCase):
         for cidr in BAD_CIDRS_INPUT:
             self.assertRaises(ValidationError, ip.validate, cidr)
 
+    def test_mac_address_validator(self):
+        GOOD_MAC_ADDRESSES = (
+            "00:11:88:99:Aa:Ff",
+            "00-11-88-99-Aa-Ff",
+            "0011.8899.AaFf",
+            "00118899AaFf",
+        )
+        BAD_MAC_ADDRESSES = (
+            "not a mac",
+            "11:22:33:44:55",
+            "zz:11:22:33:44:55",
+        )
+
+        field = forms.MACAddressField()
+        for input in GOOD_MAC_ADDRESSES:
+            self.assertIsNone(field.validate(input))
+        for input in BAD_MAC_ADDRESSES:
+            self.assertRaises(ValidationError, field.validate, input)
+
+    def test_mac_address_normal_form(self):
+        field = forms.MACAddressField()
+        field.validate("00-11-88-99-Aa-Ff")
+        self.assertEqual(field.mac_address, "00:11:88:99:aa:ff")
+
     def test_port_validator(self):
         VALID_PORTS = (1, 65535)
         INVALID_PORTS = (-1, 65536)
@@ -231,8 +255,8 @@ class ValidatorsTests(test.TestCase):
                               icmp_code)
 
     def test_ip_proto_validator(self):
-        VALID_PROTO = (0, 255)
-        INVALID_PROTO = (-1, 256)
+        VALID_PROTO = (0, 255, -1)
+        INVALID_PROTO = (-2, 256)
 
         for proto in VALID_PROTO:
             self.assertIsNone(validators.validate_ip_protocol(proto))
