@@ -23,11 +23,10 @@ from django import http
 from django.test.utils import override_settings
 from django.utils import timezone
 
-from mox3.mox import IgnoreArg  # noqa
-from mox3.mox import IsA  # noqa
+from mox3.mox import IgnoreArg
+from mox3.mox import IsA
 
 from horizon.workflows import views
-from openstack_auth import policy as policy_backend
 
 from openstack_dashboard import api
 from openstack_dashboard.dashboards.identity.projects import workflows
@@ -95,9 +94,16 @@ class TenantsViewTests(test.BaseAdminViewTests):
         self.assertItemsEqual(res.context['table'].data, domain_tenants)
         self.assertContains(res, "<em>test_domain:</em>")
 
+    @test.update_settings(FILTER_DATA_FIRST={'identity.projects': True})
+    def test_index_with_filter_first(self):
+        res = self.client.get(INDEX_URL)
+        self.assertTemplateUsed(res, 'identity/projects/index.html')
+        projects = res.context['table'].data
+        self.assertItemsEqual(projects, [])
+
 
 class ProjectsViewNonAdminTests(test.TestCase):
-    @override_settings(POLICY_CHECK_FUNCTION=policy_backend.check)
+    @override_settings(POLICY_CHECK_FUNCTION='openstack_auth.policy.check')
     @test.create_stubs({api.keystone: ('tenant_list',
                                        'domain_lookup')})
     def test_index(self):
@@ -186,7 +192,8 @@ class CreateProjectWorkflowTests(test.BaseAdminViewTests):
                                        'role_list'),
                         api.base: ('is_service_enabled',),
                         api.cinder: ('is_volume_service_enabled',),
-                        api.neutron: ('is_extension_supported',),
+                        api.neutron: ('is_extension_supported',
+                                      'is_router_enabled',),
                         quotas: ('get_default_quota_data',)})
     def test_add_project_get(self):
         quota = self.quotas.first()
@@ -208,6 +215,8 @@ class CreateProjectWorkflowTests(test.BaseAdminViewTests):
             .AndReturn(default_domain)
         api.neutron.is_extension_supported(
             IsA(http.HttpRequest), 'security-group').AndReturn(True)
+        api.neutron.is_router_enabled(
+            IsA(http.HttpRequest)).AndReturn(True)
         quotas.get_default_quota_data(IsA(http.HttpRequest)).AndReturn(quota)
 
         api.keystone.get_default_role(IsA(http.HttpRequest)) \
@@ -255,7 +264,8 @@ class CreateProjectWorkflowTests(test.BaseAdminViewTests):
                                        'role_list',
                                        'domain_get'),
                         api.neutron: ('is_extension_supported',
-                                      'tenant_quota_get'),
+                                      'tenant_quota_get',
+                                      'is_router_enabled',),
                         quotas: ('get_default_quota_data',)})
     @test.update_settings(OPENSTACK_NEUTRON_NETWORK={'enable_quotas': True})
     def test_add_project_get_with_neutron(self):
@@ -268,6 +278,8 @@ class CreateProjectWorkflowTests(test.BaseAdminViewTests):
             .MultipleTimes().AndReturn(True)
         api.neutron.is_extension_supported(
             IsA(http.HttpRequest), 'security-group').AndReturn(True)
+        api.neutron.is_router_enabled(
+            IsA(http.HttpRequest)).AndReturn(True)
         api.neutron.tenant_quota_get(IsA(http.HttpRequest),
                                      tenant_id=self.tenant.id) \
             .AndReturn(neutron_quotas)
@@ -287,11 +299,11 @@ class CreateProjectWorkflowTests(test.BaseAdminViewTests):
 
         self.assertTemplateUsed(res, views.WorkflowView.template_name)
         if django.VERSION >= (1, 10):
-            pattern = ('<input class="form-control" '
+            pattern = ('<input autocomplete="off" class="form-control" '
                        'id="id_subnet" min="-1" '
                        'name="subnet" type="number" value="10" required/>')
         else:
-            pattern = ('<input class="form-control" '
+            pattern = ('<input autocomplete="off" class="form-control" '
                        'id="id_subnet" min="-1" '
                        'name="subnet" type="number" value="10"/>')
         self.assertContains(res, pattern, html=True)
@@ -373,7 +385,7 @@ class CreateProjectWorkflowTests(test.BaseAdminViewTests):
                                                 project=self.tenant.id)
 
         nova_updated_quota = {key: quota_data[key] for key in
-                              set(quotas.NOVA_QUOTA_FIELDS) - disabled_quotas}
+                              quotas.NOVA_QUOTA_FIELDS - disabled_quotas}
         quotas.get_disabled_quotas(IsA(http.HttpRequest)) \
             .AndReturn(disabled_quotas)
         api.nova.tenant_quota_update(IsA(http.HttpRequest),
@@ -592,7 +604,7 @@ class CreateProjectWorkflowTests(test.BaseAdminViewTests):
                                                 project=self.tenant.id)
 
         nova_updated_quota = {key: quota_data[key] for key in
-                              set(quotas.NOVA_QUOTA_FIELDS) - disabled_quotas}
+                              quotas.NOVA_QUOTA_FIELDS - disabled_quotas}
         quotas.get_disabled_quotas(IsA(http.HttpRequest)) \
             .AndReturn(disabled_quotas)
         api.nova.tenant_quota_update(IsA(http.HttpRequest),
@@ -676,7 +688,7 @@ class CreateProjectWorkflowTests(test.BaseAdminViewTests):
             break
 
         nova_updated_quota = {key: quota_data[key] for key in
-                              set(quotas.NOVA_QUOTA_FIELDS) - disabled_quotas}
+                              quotas.NOVA_QUOTA_FIELDS - disabled_quotas}
         quotas.get_disabled_quotas(IsA(http.HttpRequest)) \
             .AndReturn(disabled_quotas)
         api.nova.tenant_quota_update(IsA(http.HttpRequest),
@@ -1059,11 +1071,12 @@ class UpdateProjectWorkflowTests(test.BaseAdminViewTests):
         self._check_role_list(keystone_api_version, role_assignments, groups,
                               proj_users, roles, workflow_data)
 
-        quotas.tenant_quota_usages(IsA(http.HttpRequest), tenant_id=project.id) \
+        quotas.tenant_quota_usages(IsA(http.HttpRequest),
+                                   tenant_id=project.id) \
             .AndReturn(quota_usages)
 
         nova_updated_quota = {key: updated_quota[key] for key in
-                              set(quotas.NOVA_QUOTA_FIELDS) - disabled_quotas}
+                              quotas.NOVA_QUOTA_FIELDS - disabled_quotas}
         quotas.get_disabled_quotas(IsA(http.HttpRequest)) \
             .AndReturn(disabled_quotas)
         api.nova.tenant_quota_update(IsA(http.HttpRequest),
@@ -1218,7 +1231,8 @@ class UpdateProjectWorkflowTests(test.BaseAdminViewTests):
         updated_quota = self._get_quota_info(quota)
 
         # handle
-        quotas.tenant_quota_usages(IsA(http.HttpRequest), tenant_id=project.id) \
+        quotas.tenant_quota_usages(IsA(http.HttpRequest),
+                                   tenant_id=project.id) \
             .AndReturn(quota_usages)
 
         api.keystone.get_effective_domain_id(
@@ -1350,11 +1364,12 @@ class UpdateProjectWorkflowTests(test.BaseAdminViewTests):
         self._check_role_list(keystone_api_version, role_assignments, groups,
                               proj_users, roles, workflow_data)
 
-        quotas.tenant_quota_usages(IsA(http.HttpRequest), tenant_id=project.id) \
+        quotas.tenant_quota_usages(IsA(http.HttpRequest),
+                                   tenant_id=project.id) \
             .AndReturn(quota_usages)
 
         nova_updated_quota = {key: updated_quota[key] for key in
-                              set(quotas.NOVA_QUOTA_FIELDS) - disabled_quotas}
+                              quotas.NOVA_QUOTA_FIELDS - disabled_quotas}
         quotas.get_disabled_quotas(IsA(http.HttpRequest)) \
             .AndReturn(disabled_quotas)
         api.nova.tenant_quota_update(IsA(http.HttpRequest),
@@ -1463,7 +1478,8 @@ class UpdateProjectWorkflowTests(test.BaseAdminViewTests):
         updated_quota = self._get_quota_info(quota)
 
         # handle
-        quotas.tenant_quota_usages(IsA(http.HttpRequest), tenant_id=project.id) \
+        quotas.tenant_quota_usages(IsA(http.HttpRequest),
+                                   tenant_id=project.id) \
             .AndReturn(quota_usages)
 
         api.keystone.get_effective_domain_id(
@@ -1554,20 +1570,20 @@ class UsageViewTests(test.BaseAdminViewTests):
 
     def _stub_neutron_api_calls(self, neutron_sg_enabled=True):
         self.mox.StubOutWithMock(api.neutron, 'is_extension_supported')
-        self.mox.StubOutWithMock(api.network, 'floating_ip_supported')
-        self.mox.StubOutWithMock(api.network, 'tenant_floating_ip_list')
+        self.mox.StubOutWithMock(api.neutron, 'floating_ip_supported')
+        self.mox.StubOutWithMock(api.neutron, 'tenant_floating_ip_list')
         if neutron_sg_enabled:
-            self.mox.StubOutWithMock(api.network, 'security_group_list')
+            self.mox.StubOutWithMock(api.neutron, 'security_group_list')
         api.neutron.is_extension_supported(
             IsA(http.HttpRequest),
             'security-group').AndReturn(neutron_sg_enabled)
-        api.network.floating_ip_supported(IsA(http.HttpRequest)) \
+        api.neutron.floating_ip_supported(IsA(http.HttpRequest)) \
             .AndReturn(True)
-        api.network.tenant_floating_ip_list(IsA(http.HttpRequest)) \
+        api.neutron.tenant_floating_ip_list(IsA(http.HttpRequest)) \
             .AndReturn(self.floating_ips.list())
         if neutron_sg_enabled:
-            api.network.security_group_list(IsA(http.HttpRequest)) \
-                .AndReturn(self.q_secgroups.list())
+            api.neutron.security_group_list(IsA(http.HttpRequest)) \
+                .AndReturn(self.security_groups.list())
 
     def test_usage_csv(self):
         self._test_usage_csv(nova_stu_enabled=True)
