@@ -137,7 +137,6 @@
       allowedBootSources: [],
       images: [],
       allowCreateVolumeFromImage: false,
-      arePortProfilesSupported: false,
       imageSnapshots: [],
       keypairs: [],
       metadataDefs: {
@@ -151,7 +150,6 @@
       ports: [],
       neutronEnabled: false,
       novaLimits: {},
-      profiles: [],
       securityGroups: [],
       serverGroups: [],
       volumeBootable: false,
@@ -160,6 +158,14 @@
       metadataTree: null,
       hintsTree: null,
 
+      /**
+       * This is to inform users current situation is under loading or not
+       */
+      loaded: {
+        // Availability Zones on Details tab
+        availabilityZones: false
+      },
+
       /**
        * api methods for UI controllers
        */
@@ -187,7 +193,6 @@
         name: null,
         networks: [],
         ports: [],
-        profile: {},
         scheduler_hints: {},
         // REQUIRED Server Key. May be empty.
         security_groups: [],
@@ -205,6 +210,12 @@
       };
     }
 
+    function initializeLoadStatus() {
+      angular.forEach(model.loaded, function(val, key) {
+        model.loaded[key] = false;
+      });
+    }
+
     /**
      * @ngdoc method
      * @name launchInstanceModel.initialize
@@ -220,6 +231,7 @@
       // Each time opening launch instance wizard, we need to do this, or
       // we can call the whole methods `reset` instead of `initialize`.
       initializeNewInstanceSpec();
+      initializeLoadStatus();
 
       if (model.initializing) {
         promise = initPromise;
@@ -237,7 +249,8 @@
         var launchInstanceDefaults = settings.getSetting('LAUNCH_INSTANCE_DEFAULTS');
 
         promise = $q.all([
-          novaAPI.getAvailabilityZones().then(onGetAvailabilityZones, noop),
+          novaAPI.getAvailabilityZones().then(onGetAvailabilityZones)
+            .finally(onGetAvailabilityZonesComplete),
           novaAPI.getFlavors({
             is_public: true,
             get_extras: true
@@ -357,6 +370,10 @@
 
     }
 
+    function onGetAvailabilityZonesComplete() {
+      model.loaded.availabilityZones = true;
+    }
+
     // Flavors
 
     function onGetFlavors(data) {
@@ -431,9 +448,9 @@
     // Server Groups
 
     function getServerGroups() {
-      if (policy.check(stepPolicy.serverGroups)) {
-        return novaAPI.getServerGroups().then(onGetServerGroups, noop);
-      }
+      policy.ifAllowed(stepPolicy.serverGroups).then(function() {
+        novaAPI.getServerGroups().then(onGetServerGroups, noop);
+      }, noop);
     }
 
     function onGetServerGroups(data) {
@@ -552,14 +569,10 @@
     function addVolumeSourcesIfEnabled(config) {
       var volumeDeferred = $q.defer();
       var volumeSnapshotDeferred = $q.defer();
+      var absoluteLimitsDeferred = $q.defer();
       serviceCatalog
-        .ifTypeEnabled('volume')
-        .then(onVolumeServiceEnabled, onCheckVolumeV2);
-      function onCheckVolumeV2() {
-        serviceCatalog
-          .ifTypeEnabled('volumev2')
-          .then(onVolumeServiceEnabled, onCheckVolumeV3);
-      }
+        .ifTypeEnabled('volumev2')
+        .then(onVolumeServiceEnabled, onCheckVolumeV3);
       function onCheckVolumeV3() {
         serviceCatalog
           .ifTypeEnabled('volumev3')
@@ -572,8 +585,10 @@
           .then(onBootToVolumeSupported);
         if (!config || !config.disable_volume) {
           getVolumes().then(resolveVolumes, failVolumes);
+          getAbsoluteLimits().then(resolveAbsoluteLimitsDeferred, resolveAbsoluteLimitsDeferred);
         } else {
           resolveVolumes();
+          resolveAbsoluteLimitsDeferred();
         }
         if (!config || !config.disable_volume_snapshot) {
           getVolumeSnapshots().then(resolveVolumeSnapshots, failVolumeSnapshots);
@@ -588,6 +603,9 @@
         return cinderAPI.getVolumes({status: 'available', bootable: 1})
           .then(onGetVolumes);
       }
+      function getAbsoluteLimits() {
+        return cinderAPI.getAbsoluteLimits().then(onGetCinderLimits);
+      }
       function getVolumeSnapshots() {
         return cinderAPI.getVolumeSnapshots({status: 'available'})
           .then(onGetVolumeSnapshots);
@@ -595,6 +613,7 @@
       function resolvePromises() {
         volumeDeferred.resolve();
         volumeSnapshotDeferred.resolve();
+        absoluteLimitsDeferred.resolve();
       }
       function resolveVolumes() {
         volumeDeferred.resolve();
@@ -608,10 +627,14 @@
       function failVolumeSnapshots() {
         volumeSnapshotDeferred.resolve();
       }
+      function resolveAbsoluteLimitsDeferred() {
+        absoluteLimitsDeferred.resolve();
+      }
       return $q.all(
         [
           volumeDeferred.promise,
-          volumeSnapshotDeferred.promise
+          volumeSnapshotDeferred.promise,
+          absoluteLimitsDeferred.promise
         ]);
     }
 
@@ -708,11 +731,9 @@
     function setFinalSpecBootImageToVolume(finalSpec) {
       if (finalSpec.vol_create) {
         // Specify null to get Autoselection (not empty string)
-        var deviceName = finalSpec.vol_device_name ? finalSpec.vol_device_name : null;
         finalSpec.block_device_mapping_v2 = [];
         finalSpec.block_device_mapping_v2.push(
           {
-            'device_name': deviceName,
             'source_type': bootSourceTypes.IMAGE,
             'destination_type': bootSourceTypes.VOLUME,
             'delete_on_termination': finalSpec.vol_delete_on_instance_delete,
@@ -739,6 +760,12 @@
       finalSpec.source_id = '';
     }
 
+    // Cinder Limits
+
+    function onGetCinderLimits(response) {
+      model.cinderLimits = response.data;
+    }
+
     // Nova Limits
 
     function onGetNovaLimits(data) {
