@@ -11,9 +11,12 @@
 # under the License.
 
 import os
+import tempfile
+
+import six
 
 from django.utils.translation import pgettext_lazy
-from horizon.test.settings import *  # noqa
+from horizon.test.settings import *  # noqa: F403,H303
 from horizon.utils import secret_key
 from openstack_dashboard import exceptions
 
@@ -34,7 +37,7 @@ STATIC_URL = '/static/'
 WEBROOT = '/'
 
 SECRET_KEY = secret_key.generate_or_read_from_file(
-    os.path.join(TEST_DIR, '.secret_key_store'))
+    os.path.join(tempfile.gettempdir(), '.secret_key_store'))
 ROOT_URLCONF = 'openstack_dashboard.test.urls'
 
 TEMPLATES[0]['DIRS'] = [
@@ -60,6 +63,14 @@ AVAILABLE_THEMES = [
     ),
 ]
 
+SELECTABLE_THEMES = [
+    (
+        'default',
+        pgettext_lazy('Default style theme', 'Default'),
+        'themes/default'
+    ),
+]
+
 # Theme Static Directory
 THEME_COLLECTION_DIR = 'themes'
 
@@ -98,7 +109,9 @@ HORIZON_CONFIG = {
 }
 
 ANGULAR_FEATURES = {
-    'images_panel': False  # Use the legacy panel so unit tests are still run
+    'images_panel': False,  # Use the legacy panel so unit tests are still run
+    'flavors_panel': False,
+    'roles_panel': False,
 }
 
 STATICFILES_DIRS = settings_utils.get_xstatic_dirs(
@@ -117,9 +130,7 @@ settings_utils.update_dashboards(
     INSTALLED_APPS,
 )
 
-# Remove this when the legacy panel is removed, along with its tests and
-# the stacks MappingsTests are updated with the new URL path.
-HORIZON_CONFIG['swift_panel'] = 'legacy'
+OPENSTACK_PROFILER = {'enabled': False}
 
 settings_utils.find_static_files(HORIZON_CONFIG, AVAILABLE_THEMES,
                                  THEME_COLLECTION_DIR, ROOT_PATH)
@@ -163,18 +174,7 @@ OPENSTACK_CINDER_FEATURES = {
 OPENSTACK_NEUTRON_NETWORK = {
     'enable_router': True,
     'enable_quotas': False,  # Enabled in specific tests only
-    # Parameters below (enable_lb, enable_firewall, enable_vpn)
-    # control if these panels are displayed or not,
-    # i.e. they only affect the navigation menu.
-    # These panels are registered even if enable_XXX is False,
-    # so we don't need to set them to True in most unit tests
-    # to avoid stubbing neutron extension check calls.
-    'enable_lb': False,
-    'enable_firewall': False,
-    'enable_vpn': False,
-    'profile_support': None,
     'enable_distributed_router': False,
-    # 'profile_support': 'cisco'
 }
 
 OPENSTACK_HYPERVISOR_FEATURES = {
@@ -189,6 +189,7 @@ OPENSTACK_IMAGE_BACKEND = {
         ('ami', 'AMI - Amazon Machine Image'),
         ('ari', 'ARI - Amazon Ramdisk Image'),
         ('iso', 'ISO - Optical Disk Image'),
+        ('ploop', 'PLOOP - Virtuozzo/Parallels Loopback Disk'),
         ('qcow2', 'QCOW2 - QEMU Emulator'),
         ('raw', 'Raw'),
         ('vdi', 'VDI'),
@@ -250,6 +251,20 @@ NOSE_ARGS = ['--nocapture',
              '--cover-package=openstack_dashboard',
              '--cover-inclusive',
              '--all-modules']
+# TODO(amotoki): Need to investigate why --with-html-output
+# is unavailable in python3.
+# NOTE(amotoki): Most horizon plugins import this module in their test
+# settings and they do not necessarily have nosehtmloutput in test-reqs.
+# Assuming nosehtmloutput potentially breaks plugins tests,
+# we check the availability of htmloutput module (from nosehtmloutput).
+try:
+    import htmloutput  # noqa: F401
+    has_html_output = True
+except ImportError:
+    has_html_output = False
+if six.PY2 and has_html_output:
+    NOSE_ARGS += ['--with-html-output',
+                  '--html-out-file=ut_openstack_dashboard_nose_results.html']
 
 POLICY_FILES_PATH = os.path.join(ROOT_PATH, "conf")
 POLICY_FILES = {
@@ -267,3 +282,34 @@ REST_API_REQUIRED_SETTINGS = ['REST_API_SETTING_1']
 REST_API_ADDITIONAL_SETTINGS = ['REST_API_SETTING_2']
 
 ALLOWED_PRIVATE_SUBNET_CIDR = {'ipv4': [], 'ipv6': []}
+
+
+# --------------------
+# Test-only settings
+# --------------------
+# TEST_GLOBAL_MOCKS_ON_PANELS: defines what and how methods should be
+# mocked globally for unit tests and Selenium tests.
+# 'method' is required. 'return_value' and 'side_effect'
+# are optional and passed to mock.patch().
+TEST_GLOBAL_MOCKS_ON_PANELS = {
+    'aggregates': {
+        'method': ('openstack_dashboard.dashboards.admin'
+                   '.aggregates.panel.Aggregates.can_access'),
+        'return_value': True,
+    },
+    'domains': {
+        'method': ('openstack_dashboard.dashboards.identity'
+                   '.domains.panel.Domains.can_access'),
+        'return_value': True,
+    },
+    'trunk': {
+        'method': ('openstack_dashboard.dashboards.project'
+                   '.trunks.panel.Trunks.can_access'),
+        'return_value': True,
+    },
+    'qos': {
+        'method': ('openstack_dashboard.dashboards.project'
+                   '.network_qos.panel.NetworkQoS.can_access'),
+        'return_value': True,
+    },
+}
